ImagePicker2 class

Constructors

ImagePicker2()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

pickImages({required int limit, int? maxWidth, int? quality}) Future<List<String>?>
pickMedia({required int limit, PickerMediaType type = PickerMediaType.image, int? maxWidth, int? quality}) Future<List<String>?>
Pick multiple images/videos with a specific limit, quality and max width