ImagePicker2Platform class abstract

Inheritance
  • Object
  • PlatformInterface
  • ImagePicker2Platform
Implementers

Constructors

ImagePicker2Platform()
Constructs a ImagePicker2Platform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pickMedia({required int limit, PickerMediaType type = PickerMediaType.image, int? maxWidth, int? quality}) Future<List<String>?>
Core API that platform implementations must support.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ImagePicker2Platform
The default instance of ImagePicker2Platform to use.
getter/setter pair